/* grafgen : Precision graphical genotypes based on marker informations */
/* Copyright 2002 Bertrand Servin, Christine Dillmann, Guy Decoux and Frederic Hospital */
/* Institution :
   Station de Genetique Vegetale INRA / UPS / INAPG 
   91190 Gif-sur-Yvette - FRANCE */

/*     This file is part of Grafgen. */

/*     Grafgen is free software; you can redistribute it and/or modify */
/*     it under the terms of the GNU General Public License as published by */
/*     the Free Software Foundation; either version 2 of the License, or */
/*     (at your option) any later version. */

/*     Grafgen is distributed in the hope that it will be useful, */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of */
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
/*     GNU General Public License for more details. */

/*     You should have received a copy of the GNU General Public License */
/*     along with Grafgen; if not, write to the Free Software */
/*     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */


/* Please report Bugs and Comments to servin@stat.washington.edu */
   

#include "grafgen.h"

#include <math.h>
#include <stdio.h>


double ttest_pval(double r)
{
    /* t-test quantiles:
       - 10%
       - 5% 
       - 2.5% 
       - 0.5% 
       with a sample of size 30 */
    const double t10=1.31042, t5=1.69726, t2_5=2.04227,t0_5=2.75;
    static short sign=1;
    /* Ideally we want to return 1-pvalue  */
    if (r<0) {
	r=-r;
	sign=-1;
    }
    if (r>t0_5) return sign*1;
    if (r>t2_5) return sign*0.75;
    if (r>t5) return sign*0.50;
    if (r>t10) return sign*0.25;
    return 0;
}

/* Place here the functions to compute RGB Values from results */
/* threshold */
void thresh(r) 
	double r;

{
	if (r >= 0)
		rgb[(int)(r)] = 255;
}



/* Black & White */

void BW(r)
	double r;
{
    if (r<0) r=-r;
    r = 1-r;
    rgb[0] = (int)(255*r);
    rgb[1] = (int)(255*r);
    rgb[2] = (int)(255*r);
}
/* Hot hot hot */
void heat(r)
	double r;
{
    if (r<0) r=-r;
    
    r = 1-r; 
    rgb[0] = 255;
    rgb[1] = (360*r > 255) ? 255 : (int)(360*r);
    rgb[2] = (rgb[1] == 255) ? (int)(2*(360*r - 255)) : 0;
}

/*-1 (blue) -> 0 (white) -> 1 (red)*/
void bluewhitered(r)
    double r;
{
    if (r<0) {
	r=1+r;
	rgb[0]=(int)(255*r);
	rgb[1]=(int)(255*r);
	rgb[2]=255;
    }
    else {
	r=1-r;
	rgb[0]=255;
	rgb[1]=(int)(255*r);
	rgb[2]=(int)(255*r);
    }
}
